@@ -410,10 +410,6 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'LEONT/experimental-0.022.tar.gz',
         'FILES'        => q[cpan/experimental],
         'EXCLUDED'     => [qr{^xt/}],
-        'CUSTOMIZED'   => [
-	    # smartmatch changes
-	    't/basic.t',
-        ],
     },
 
     'Exporter' => {
@@ -808,7 +804,7 @@ use File::Glob qw(:case);
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20210320.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20210420.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
