@@ -14,10 +14,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(struct);
 
-$VERSION = '0.61';
-
-## Tested on 5.002 and 5.003 without class membership tests:
-my $CHECK_CLASS_MEMBERSHIP = ($] >= 5.003_95);
+$VERSION = '0.66';
 
 my $print = 0;
 sub printem {
@@ -61,7 +58,7 @@ sub import {
 	# do we ever export anything else than 'struct'...?
       $self->export_to_level( 1, $self, @_ );
     } else {
-      &struct;
+      goto &struct;
     }
 }
 
@@ -130,6 +127,9 @@ sub struct {
     elsif( $base_type eq 'ARRAY' ){
         $out .= "    my(\$r) = [];\n";
     }
+
+    $out .= " bless \$r, \$class;\n\n";
+
     while( $idx < @decls ){
         $name = $decls[$idx];
         $type = $decls[$idx+1];
@@ -150,24 +150,24 @@ sub struct {
         if( $type eq '@' ){
             $out .= "    croak 'Initializer for $name must be array reference'\n"; 
             $out .= "        if defined(\$init{'$name'}) && ref(\$init{'$name'}) ne 'ARRAY';\n";
-            $out .= "    \$r->$elem = $init [];$cmt\n"; 
+            $out .= "    \$r->$name( $init [] );$cmt\n"; 
             $arrays{$name}++;
         }
         elsif( $type eq '%' ){
             $out .= "    croak 'Initializer for $name must be hash reference'\n";
             $out .= "        if defined(\$init{'$name'}) && ref(\$init{'$name'}) ne 'HASH';\n";
-            $out .= "    \$r->$elem = $init {};$cmt\n";
+            $out .= "    \$r->$name( $init {} );$cmt\n";
             $hashes{$name}++;
         }
         elsif ( $type eq '$') {
-            $out .= "    \$r->$elem = $init undef;$cmt\n";
+            $out .= "    \$r->$name( $init undef );$cmt\n";
         }
         elsif( $type =~ /^\w+(?:::\w+)*$/ ){
             $out .= "    if (defined(\$init{'$name'})) {\n";
            $out .= "       if (ref \$init{'$name'} eq 'HASH')\n";
-            $out .= "            { \$r->$elem = $type->new(\%{\$init{'$name'}}) } $cmt\n";
+            $out .= "            { \$r->$name( $type->new(\%{\$init{'$name'}}) ) } $cmt\n";
            $out .= "       elsif (UNIVERSAL::isa(\$init{'$name'}, '$type'))\n";
-            $out .= "            { \$r->$elem = \$init{'$name'} } $cmt\n";
+            $out .= "            { \$r->$name( \$init{'$name'} ) } $cmt\n";
             $out .= "       else { croak 'Initializer for $name must be hash or $type reference' }\n";
             $out .= "    }\n";
             $classes{$name} = $type;
@@ -178,7 +178,8 @@ sub struct {
         }
         $idx += 2;
     }
-    $out .= "    bless \$r, \$class;\n  }\n";
+
+    $out .= "\n \$r;\n}\n";
 
     # Create accessor methods.
 
@@ -216,9 +217,7 @@ sub struct {
                 $sel = "->{\$i}";
             }
             elsif( defined $classes{$name} ){
-                if ( $CHECK_CLASS_MEMBERSHIP ) {
-                    $out .= "    croak '$name argument is wrong class' if \@_ && ! UNIVERSAL::isa(\$_[0], '$classes{$name}');\n";
-                }
+                $out .= "    croak '$name argument is wrong class' if \@_ && ! UNIVERSAL::isa(\$_[0], '$classes{$name}');\n";
             }
             $out .= "    croak 'Too many args to $name' if \@_ > 1;\n";
             $out .= "    \@_ ? ($pre\$r->$elem$sel = shift$pst) : $pre\$r->$elem$sel$pst;\n";
@@ -263,8 +262,13 @@ Class::Struct - declare struct-like datatypes as Perl classes
     struct( ELEMENT_NAME => ELEMENT_TYPE, ... );
 
     # Declare struct at compile time
-    use Class::Struct CLASS_NAME => [ ELEMENT_NAME => ELEMENT_TYPE, ... ];
-    use Class::Struct CLASS_NAME => { ELEMENT_NAME => ELEMENT_TYPE, ... };
+    use Class::Struct CLASS_NAME => [ELEMENT_NAME => ELEMENT_TYPE, ...];
+    use Class::Struct CLASS_NAME => {ELEMENT_NAME => ELEMENT_TYPE, ...};
+
+    # declare struct at compile time, based on array, implicit
+    # class name:
+    package CLASS_NAME;
+    use Class::Struct ELEMENT_NAME => ELEMENT_TYPE, ... ;
 
     package Myobj;
     use Class::Struct;
@@ -371,7 +375,7 @@ on the declared type of the element.
 =item Scalar (C<'$'> or C<'*$'>)
 
 The element is a scalar, and by default is initialized to C<undef>
-(but see L<Initializing with new>).
+(but see L</Initializing with new>).
 
 The accessor's argument, if any, is assigned to the element.
 
@@ -456,27 +460,28 @@ See Example 3 below for an example of initialization.
 =item Example 1
 
 Giving a struct element a class type that is also a struct is how
-structs are nested.  Here, C<timeval> represents a time (seconds and
-microseconds), and C<rusage> has two elements, each of which is of
-type C<timeval>.
+structs are nested.  Here, C<Timeval> represents a time (seconds and
+microseconds), and C<Rusage> has two elements, each of which is of
+type C<Timeval>.
 
     use Class::Struct;
 
-    struct( rusage => {
-        ru_utime => timeval,  # seconds
-        ru_stime => timeval,  # microseconds
+    struct( Rusage => {
+        ru_utime => 'Timeval',  # user time used
+        ru_stime => 'Timeval',  # system time used
     });
 
-    struct( timeval => [
-        tv_secs  => '$',
-        tv_usecs => '$',
+    struct( Timeval => [
+        tv_secs  => '$',        # seconds
+        tv_usecs => '$',        # microseconds
     ]);
 
-        # create an object:
-    my $t = new rusage;
+    # create an object:
+    my $t = Rusage->new(ru_utime=>Timeval->new(),
+        ru_stime=>Timeval->new());
 
-        # $t->ru_utime and $t->ru_stime are objects of type timeval.
-        # set $t->ru_utime to 100.0 sec and $t->ru_stime to 5.0 sec.
+    # $t->ru_utime and $t->ru_stime are objects of type Timeval.
+    # set $t->ru_utime to 100.0 sec and $t->ru_stime to 5.0 sec.
     $t->ru_utime->tv_secs(100);
     $t->ru_utime->tv_usecs(0);
     $t->ru_stime->tv_secs(5);
@@ -500,10 +505,10 @@ accessor accordingly.
         my $self = shift;
         if ( @_ ) {
             die 'count must be nonnegative' if $_[0] < 0;
-            $self->{'count'} = shift;
+            $self->{'MyObj::count'} = shift;
             warn "Too many args to count" if @_;
         }
-        return $self->{'count'};
+        return $self->{'MyObj::count'};
     }
 
     package main;
@@ -546,16 +551,16 @@ that are passed on to the nested struct's constructor.
     ];
 
 
-    my $cat = Cat->new( name     => 'Socks',
-                        kittens  => ['Monica', 'Kenneth'],
-                        markings => { socks=>1, blaze=>"white" },
-                        breed    => Breed->new(name=>'short-hair', cross=>1),
-                   or:  breed    => {name=>'short-hair', cross=>1},
+    my $cat = Cat->new( name => 'Socks',
+               kittens  => ['Monica', 'Kenneth'],
+               markings => { socks=>1, blaze=>"white" },
+               breed    => Breed->new(name=>'short-hair', cross=>1),
+          or:  breed    => {name=>'short-hair', cross=>1},
                       );
 
     print "Once a cat called ", $cat->name, "\n";
     print "(which was a ", $cat->breed->name, ")\n";
-    print "had two kittens: ", join(' and ', @{$cat->kittens}), "\n";
+    print "had 2 kittens: ", join(' and ', @{$cat->kittens}), "\n";
 
 =back
 
@@ -626,7 +631,7 @@ Originally C<Class::Template> by Dean Roehrich.
     #  - Now using my() rather than local().
     #
     # Uses perl5 classes to create nested data types.
-    # This is offered as one implementation of Tom Christiansen's "structs.pl"
-    # idea.
+    # This is offered as one implementation of Tom Christiansen's
+    # "structs.pl" idea.
 
 =cut
